%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate plot representing hrss@50% for each waveform versus its mean frequency for O3b.
% For each waveform the best result is taken between Zebragard, Lonetrack, X-pipeline and cWB.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% USER PARAMETERS
WVFS = {'adiB',...
        'GRBplateauShort',...
        'ISCOchirpA','ISCOchirpB','ISCOchirpC',...
        'NCSACAM_A','NCSACAM_B','NCSACAM_C','NCSACAM_D','NCSACAM_E','NCSACAM_F','NCSACAM_G','NCSACAM_H','NCSACAM_I',...
        'maXgnetarD','maXgnetarE','maXgnetarF', 'wnbA', 'sgC'};

XLIM = [24 2000];
Y_E_LIM = [1e-9 10];
Y_H_LIM = [1e-24 1e-18];

% Load O3 results
RESULTS_O3a; % T
RESULTS_O3b; % Tb
Ta = T;
% Load O3b ASDs
% H1 : https://dcc.ligo.org/LIGO-G2001364
% L1 : https://dcc.ligo.org/LIGO-G2001365
H = load('PSDs/H1asd_O3b.txt');
L = load('PSDs/L1asd_O3b.txt');
V = load('PSDs/V1asd_O3.txt');
import classes.waveforms.dictionary
dic = dictionary;

%% HRSS figure %%
figure('position',[0 0 800 600]);
hg=hggroup;
colormap parula;

ax=gca();
hold all

% Plot PSD
loglog(H(:,1),H(:,2),'Color',[173/255 31/255 43/255]);
loglog(L(:,1),L(:,2),'Color',[62/255 195/255 3/255]);
loglog(V(:,1),V(:,2), 'Color', 'blue')
text(32,2e-24,'H1 PSD',...
     'FontSize',20,'Interpreter','latex',...
     'Color',[173/255 31/255 43/255])
text(25,6e-24,'L1 PSD',...
     'FontSize',20,'Interpreter','latex',...
     'Color',[62/255 195/255 3/255])
text(60, 3e-24, 'V1 PSD', 'FontSize', 20, 'Interpreter', 'latex', 'Color', 'blue')

% Plot energies
msun=1.988e30;        % kg
msunc2=msun*(3e8)^2;  % kg m^2 s^-2
c=2.99e8;             % m s^-1
G=6.67e-11;           % kg m^3 s^-2
X=24:0.1:2000;

E_1 = sqrt((G/c^3)*msunc2*1e-2)/pi/100000e3/3.08e16./X;
E_2 = sqrt((G/c^3)*msunc2*1e-2)/pi/10000e3/3.08e16./X;
E_3 = sqrt((G/c^3)*msunc2*1e-2)/pi/1000e3/3.08e16./X;
E_4 = sqrt((G/c^3)*msunc2*1e-2)/pi/100e3/3.08e16./X;


plot(X,E_1,'-.k');
plot(X,E_2,'-.k');
plot(X,E_3,'-.k');
plot(X,E_4,'-.k');

text(30,1.5e-19,'$0.01~\mathrm{M_{\odot}c^{2}}$ @ 100 kpc',...
     'FontSize',20,'Interpreter','latex',...
     'Rotation',-14)
text(30,1.5e-20,'$0.01~\mathrm{M_{\odot}c^{2}}$ @ 1 Mpc',...
     'FontSize',20,'Interpreter','latex',...
     'Rotation',-14)
text(30,1.5e-21,'$0.01~\mathrm{M_{\odot}c^{2}}$ @ 10 Mpc',...
     'FontSize',20,'Interpreter','latex','Rotation',-14)
text(30,1.5e-22,'$0.01~\mathrm{M_{\odot}c^{2}}$ @ 100 Mpc',...
     'FontSize',20,'Interpreter','latex','Rotation',-14)

% Plot waveforms hrss@50% vs mean frequency

%O3a - O3b
P = @(w,m,fc,ec,ms) plot(0.5*(dic.headers(w).fmin+dic.headers(w).fmax),min(Ta.(bestPip(Ta,w)).(w),Tb.(bestPip(Tb,w)).(w)) ,m,'Color','k','MarkerFaceColor',fc,'MarkerEdgeColor',ec,'MarkerSize',ms);

P('adiB','^','none','k',10)

P('GRBplateauShort','x','k','k',10)

P('ISCOchirpA','*','k','k',10)
P('ISCOchirpB','*','k','k',10)
P('ISCOchirpC','*','k','k',10)

P('NCSACAM_A','s','k','k',7)
P('NCSACAM_B','s','k','k',7)
P('NCSACAM_C','s','k','k',7)
P('NCSACAM_D','s','k','k',7)
P('NCSACAM_E','s','k','k',7)
P('NCSACAM_F','s','k','k',7)
P('NCSACAM_G','s','k','k',7)
P('NCSACAM_H','s','k','k',7)
P('NCSACAM_I','s','k','k',7)

P('maXgnetarD','>','none','k',7)
P('maXgnetarE','>','none','k',7)
P('maXgnetarF','>','none','k',7)

P('wnbA','o', 'none', 'k', 7)
%P('wnbB','o', 'none', 'k', 7)

P('sgC','p', 'k','k', 7)



plot(1,1, 'pk', 'MarkerFaceColor', 'k', 'Parent', hg);
plot(1,1, 'ok', 'Parent', hg);
plot(1,1,'>k','Parent',hg);
plot(1,1,'sk','MarkerFaceColor','k','Parent',hg);
plot(1,1,'*k','MarkerEdgeColor','k','Parent',hg);
plot(1,1,'xk','MarkerEdgeColor','k','Parent',hg);
plot(1,1,'^k','Parent',hg);

lgd=legend([hg.Children],'ADI','GRBplateau','ISCOchirp','ECBC', 'Magnetar', 'WNB', 'SG',...
       'Location','NorthEast');
hg.Visible='off';
lgd.FontSize = 18;
lgd.Position = [0.67 0.62 .2 .28];

box
grid minor
set(ax,'XScale','log')
set(ax,'YScale','log')
h = gcf;
set(h, 'PaperOrientation', 'landscape')
set(ax, 'LineWidth', 1)

xlabel('Mean frequency [Hz]',...
       'Interpreter','latex',...
       'FontSize',20);
ylabel('h$_{\mathrm rss}$ [strain/$\sqrt{\mathrm Hz}$]',...
       'Interpreter','latex',...
       'FontSize',20);
ax.FontSize=20;
xlim(XLIM)
ylim(Y_H_LIM)

print('-dpdf',['plots/all_waveforms_best_O3.pdf']);

